| act_pattern | R Documentation |
A data frame containing one activation pattern extracted from one wild type mouse walking on a treadmill.
act_pattern
A data frame of two columns:
timeNormalised time in points.
signalActivation pattern
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.