Learn R Programming

musclesyneRgies (version 1.3.1)

act_pattern: Single activation pattern example (30 cycles)

Description

A data frame containing one activation pattern extracted from one wild type mouse walking on a treadmill.

Usage

act_pattern

Arguments

Format

A data frame of two columns:

time

Normalised time in points.

signal

Activation pattern